# Upgrading to GROWI v6.1.x

GROWI v6.1 adds new features such as chart drawing by [Mermaid](https://mermaid.js.org/), detachable permissions for viewing only, and a bookmark sidebar. Many other fixes and improvements have been made to ensure stable operation of each feature in response to the fundamental changes in the v6.0 series.

<ContextualBlock context="docs-growi-org">

In addition, the supported middleware versions have been changed.

| GROWI | <= v6.0.x | v6.1.x |
| :---: | :---: | :---: |
| Node.js | 14, 16 | 16, 18 |
| MongoDB | 3.6, 4.0, 4.2, 4.4, 5 | 3.6, 4.0, 4.2, 4.4, 5, 6 |
| Elasticsearch | 6, 7 | 7, 8 |

There are changes to the execution environment and supported middleware, so admin should check the version used in their current environment before upgrading.

</ContextualBlock>

## Table of Contents

[[toc]]

<ContextualBlock context="docs-growi-org">

## For Admin

### Node.js v14 no longer supported

::: tip

- Systems using [official Docker images](https://hub.docker.com/r/weseek/growi/) are not affected
:::

- Upgrade to v16 or v18


### Elasticsearch v6 no longer supported, default version changed to v8

GROWI v6.1.0 removes code for Elasticsearch v6 and adds support for v8. Also, the default version used is now v8.

- Systems using Elasticsearch v6 should upgrade to v7 or v8
- If you want to use Elasticsearch v7, set `ELASTICSEARCH_VERSION` to `7` in [environment variables](../admin-cookbook/env-vars.html).

### Build Procedure Change

::: tip
This section is required if you are building from source code published on GitHub.  
It is not required if you are using official docker images.

:::

[Turborepo](https://turbo.build/repo) is now required as a build tool instead of Lerna, which was previously used.
Since it is not included in package.json, a global installation is required.
Please install it with the following command before building.

1. `yarn global add turbo`

For more information, see [README.md](https://github.com/weseek/growi/blob/master/README.md) and [Development Startup](../../dev/startup-v5/start-development.html).


### [Specification Change] Change File Save Location Under `FILE_UPLOAD=local` Setting

::: warning
The contents of this item are only required on systems configured to store attachments on the local file system.  
It is not required for systems storing on AWS S3, GCP GCS, or MongoDB GridFS.

:::

The location of the `app` package has changed, and the location of the files has changed.

| Before | | After |
| :-: | :-: | :-: |
| `/opt/growi/packages/app/public` | -> | `/opt/growi/apps/app/public` |

Please move existing files after upgrade.

Also see discussion below.
<https://github.com/weseek/growi/discussions/6086>

</ContextualBlock>

## For User

### [Specification Change] Elimination of `mdcont-` Prefix Automatically Added to Anchor Links

Starting with v6.0.0, any anchor link in a page (including links in the auto-generated table of contents) was automatically given the prefix `mdcont-`.

Example:
The `id` of the `Headers` section in `/Sandbox` is `#mdcont-headers`.

Starting with v6.1.0, this specification has been eliminated and the `mdcont-` prefix is no longer attached.

However, there is no problem with GROWI-generated links such as the table of contents.
If the link contains a `mdcont-` prefix in the document or if the link refers to a document or system outside of GROWI, it will not jump to the anchor when accessing the document.

<ContextualBlock context="docs-growi-org">

Please rewrite the relevant links accordingly.

::: tip
The content of pages saved using the previous notation will not automatically change when the GROWI version is upgraded.  
We have provided a script to batch rewrite Markdown documents to the new notation, please check the discussion below.
<https://github.com/weseek/growi/discussions/7180>
:::

</ContextualBlock>


<ContextualBlock context="help-growi-cloud">

::: tip
The content of pages saved using the previous notation will not automatically change when GROWI is upgraded.  
GROWI.cloud support can delete all "mdcont-" pages with heading links that exist in GROWI.
Please contact GROWI.cloud support if you wish to do so. [Inquiry Form](https://growi.cloud/contact)

※ The following operations are not handled by GROWI.cloud support.

- Assigning "mdcont-" to an external tool other than GROWI
- Deletion of "mdcont-" in GROWI headline links that exist in external tools other than GROWI
:::

</ContextualBlock>

## Check before upgrading

<ContextualBlock context="docs-growi-org">

- [x] Upgrade to Node.js v16 or higher.
- [x] Upgrade to Elasticsearch v7 or v8.
- [x] If you are building from source code, check the new build instructions.
- [x] On systems with `FILE_UPLOAD=local` setting, check the procedure for moving files after the upgrade.

</ContextualBlock>

- [x] Check the change in anchor links.
  - [x] Inform GROWI users about the change.
  - [x] Decide on a strategy for future rewrites of existing page content.
