---
title: Upgrading to GROWI v7.0.x
---

# Welcome to GROWI v7!

GROWI has completely renewed his Look & Feel since v4.2 and has been reborn into a simple and modern look.
Come experience the new layout, new theme, and new UX.

<ContextualBlock context="docs-growi-org">

::: tip
v7.0 includes a major overhaul on the client side, and unfortunately there are some areas where the behavior is unstable at the moment.
We will try to stabilize it in future updates, so we encourage all users who would like to contribute to this process to try v7.0.

For organizations with hundreds of users or more, or for those who require stable behavior in daily work, we recommend using v6.3 until v7.1 is released.
:::

</ContextualBlock>

# Upgrading to GROWI v7.0.x

<ContextualBlock context="docs-growi-org">

The supported execution environment versions have changed.

| GROWI | <= v6.3.x | v7.0.x |
| :---: | :---: | :---: |
| Node.js | 16, 18 | 18, 20 |

If you are an administrator, please check the version you are using in your current environment before upgrading.

</ContextualBlock>


## Table of Contents

[[toc]]


## For Admin

### Downgrading to v6.x Series

The version of Bootstrap used as the frontend framework has been upgraded from v4.6 to v5.3.
Markdown documents that contain HTML tags written using Bootstrap notation will be affected.

Please see the following section [Bootstrap version is upgraded to v5 series](#Specification change - bootstrap version is upgraded to v5 series).

Other than that, there are no special points to note.

<ContextualBlock context="docs-growi-org">

### Node.js v16 no longer supported

::: tip

- Systems using [official Docker images](https://hub.docker.com/r/weseek/growi/) are not affected
:::

- Upgrade to v18 or v20

</ContextualBlock>

### Upgrade to Bootstrap 5

The version of Bootstrap used as the frontend framework has been upgraded from v4.6 to v5.3.
Markdown documents that contain HTML tags written using Bootstrap notation will be affected.

Please check the official Bootstrap [Changes in v5](https://getbootstrap.jp/docs/5.3/migration/).

<ContextualBlock context="docs-growi-org">

::: tip
The content of pages saved using the previous notation will not automatically change when the GROWI is upgraded.
To use a script to bulk rewrite Markdown documents to the new notation, see the following discussion.
<https://github.com/weseek/growi/discussions/7180>
:::

</ContextualBlock>

<ContextualBlock context="help-growi-cloud">

::: tip
Content saved using the previous notation will not automatically change when upgrading GROWI versions.
If you wish to perform a bulk conversion of notation, please contact GROWI.cloud Service Desk at [Contact Us](https://growi.cloud/contact).
:::

</ContextualBlock>

### [Specification Change Due to Deprecation] Deprecation of HackMD cooperation function

The feature that allows simultaneous multi-person editing in conjunction with HackMD has been discontinued.

GROWI v7 instead allows simultaneous multi-person editing using the built-in editor. For more information,
please see the [Simultaneous multi-person editing using the built-in editor](#new-feature-simultaneous-multi-person-editing-with-built-in-editor) section.


<ContextualBlock context="docs-growi-org">

### [Specification Change Due to Deprecation] Deprecation of Promster integration function

The ability to work with Promster has been deprecated.

</ContextualBlock>


## For User

### [New Feature] WIP Page

When you create or update a page, you can now save it as a WIP (Work In Progress) page.
Please see [WIP page](/en/guide/features/wip-page.html) for more information.

### [Specification Change] Changes in new page creation flow and behavior

The button for creating a new page has been moved from the navigation bar at the top of the screen to the sidebar at the top left of the screen.
Also, the behavior when pressing the button has changed.

- up to v6
  - When the edit screen is displayed, page data has not yet been created.
  - Create page data with save operation
- v7 or later
  - When you display the edit screen, create a WIP page with a title like "Untitled-1"

#### Automatic deletion of empty new WIP pages

If the newly created page is his WIP page and does not have a body, it will be automatically deleted after a certain amount of time (48 hours by default) after creation.
However, if the page title has been changed even once after the page was created, if there is a page body,
or if the WIP status has been canceled, the page will not be deleted.


<ContextualBlock context="docs-growi-org">

::: tip
The period until automatic deletion can be changed with the environment variable `WIP_PAGE_EXPIRATION_SECONDS`.
:::

</ContextualBlock>

### [New Feature] Simultaneous multi-person editing with built-in editor

GROWI's built-in editor now allows multiple users to edit at the same time.
For more information, see [Simultaneous multi-person editing](/en/guide/features/built-in-editor.md).

### [Specification Change] Full text search

The location and usage of the full-text search function have changed. For more information, see [Search pages](/en/guide/features/search.html).

### [Specification Change] Editor Theme

The editor theme has been completely redesigned. As before v6,
individual users can choose a theme that suits their environment,
separate from the overall theme of the app.

There are 5 types of themes that support light mode and 5 types of themes that support dark mode.

### [Not Implemented] Christmas Theme

Santa Claus is on vacation and Christmas themes are disabled at this time. It is scheduled to be implemented in 2024.

If you are using one, please change to another theme on the management screen before or after the version update.


## Check before upgrading

<ContextualBlock context="docs-growi-org">

- [x] Upgrade to Node.js v18 or higher.
- [x] Bootstrap notation change.
  - [x] Inform GROWI users about the change.
  - [x] Decide on a strategy for future rewrites of existing page content.
- [x] About the new simultaneous multi-person editing feature and the HackMD server used up to v6
  - [x] Inform GROWI users about the change.
  - [x] Decide on a strategy for degrading the HackMD server.
- [x] Confirm that there will be no problems with monitoring etc. due to the discontinuation of the Promster linkage function
- [x] About new page creation process and behavior changes, WIP pages
  - [x] Inform GROWI users about the change.
- [x] About automatic deletion of empty new WIP pages
  - [x] Inform GROWI users about the change.
- [x] New full-text search behavior
  - [x] Inform GROWI users about the change.
- [x] Christmas theme has not implemented.
  - [x] Change the current theme if your system is using it.

</ContextualBlock>


<ContextualBlock context="help-growi-cloud">

- [x] Bootstrap notation change.
  - [x] Inform GROWI users about the change.
  - [x] Decide on a strategy for future rewrites of existing page content.
- [x] About the new simultaneous multi-person editing feature and the HackMD server used up to v6
  - [x] Inform GROWI users about the change.
- [x] About new page creation process and behavior changes, WIP pages
  - [x] Inform GROWI users about the change.
- [x] About automatic deletion of empty new WIP pages
  - [x] Inform GROWI users about the change.
- [x] New full-text search behavior
  - [x] Inform GROWI users about the change.
- [x] Christmas theme has not implemented.
  - [x] Change the current theme if your system is using it.

</ContextualBlock>
