# GROWI v6.1.x へのアップグレード

GROWI v6.1 では、新機能として [Mermaid](https://mermaid.js.org/) による図表描画、閲覧のみ可能とする権限の着脱、ブックマークサイドバーなどの機能が追加されました。その他に v6.0 系の抜本的な変更に対してそれぞれの機能を安定動作させるための修正や改善が多く加えられました。

<ContextualBlock context="docs-growi-org">

また、サポート対象のミドルウェアのバージョンが変更されました。

| GROWI | <= v6.0.x | v6.1.x |
| :---: | :---: | :---: |
| Node.js | 14, 16 | 16, 18 |
| MongoDB | 3.6, 4.0, 4.2, 4.4, 5 | 3.6, 4.0, 4.2, 4.4, 5, 6 |
| Elasticsearch | 6, 7 | 7, 8 |

実行環境とサポートするミドルウェアに変更がありますので、管理者の方は現在の環境で利用しているバージョンを確認してからアップグレードしてください。

</ContextualBlock>

## 目次

[[toc]]

<ContextualBlock context="docs-growi-org">

## 管理者向け

### Node.js v14 のサポートを終了

::: tip

- [公式の Docker イメージ](https://hub.docker.com/r/weseek/growi/)を利用しているシステムには影響はありません
:::

- v16 または v18 にアップグレードしてください


### Elasticsearch v6 のサポートを終了、デフォルト利用バージョンを v8 に変更

GROWI v6.1.0 では Elasticsearch v6 向けのコードを削除し、新たに v8 をサポートするようになりました。また、デフォルトの利用バージョンが v8 になりました。

- Elasticsearch v6 を利用しているシステムでは、v7 または v8 にアップグレードしてください
- Elasticsearch v7 を利用する場合は [環境変数](../admin-cookbook/env-vars.html) の `ELASTICSEARCH_VERSION` に `7` を設定してください


### ビルド手順の変更

::: tip
この項目の内容は、利用者が GitHub で公開されているソースコードから自身でビルドを行っている場合に必要です。  
公式 docker イメージを利用している方は必要ありません。  

:::

ビルドツールとしてこれまで利用してた Lerna に代わって [Turborepo](https://turbo.build/repo) が必要になりました。
また package.json には含まれていないため、グローバルインストールが必要です。
ビルドする前に以下のコマンドでインストールしてください。

1. `yarn global add turbo`

詳しくは [README.md](https://github.com/weseek/growi/blob/master/README_JP.md) および [開発スタートアップ](../../dev/startup-v5/start-development.html) をご覧ください。


### [仕様変更] `FILE_UPLOAD=local` 設定下でのファイル保存場所の変更

::: warning
この項目の内容は、添付ファイルをローカルファイルシステムに保存する設定のシステムでのみ必要です。  
AWS S3 や GCP GCS、MongoDB GridFS に保存しているシステムでは必要有りません。

:::

`app` パッケージの場所が変わったことにより、ファイルの保存場所が変更されました。

| Before | | After |
| :-: | :-: | :-: |
| `/opt/growi/packages/app/public` | -> | `/opt/growi/apps/app/public` |

アップグレード後に既存のファイルを移動させてください。

また以下のディスカッションも参照してください。  
<https://github.com/weseek/growi/discussions/6086>

</ContextualBlock>

## 利用者向け

### [仕様変更] アンカーリンクに自動付与される `mdcont-` プレフィクスの廃止

v6.0.0 から、ページ内のあらゆるアンカーリンク(自動生成される目次のリンクも含む)には `mdcont-` というプレフィクスが自動付与されていました。

例:  
`/Sandbox` 内の `Headers` セクションの `id` は `#mdcont-headers` になる。

v6.1.0 以降はこの仕様を廃止し、`mdcont-` プレフィクスが付かないようになりました。

目次等の GROWI が生成するリンクに関してはこれまで同様の利用で特に問題は起こりませんが、
`mdcont-` プレフィクスを含むリンクをドキュメント内に記述していたり、
GROWI 外の文書やシステムから参照している場合はアクセス時にアンカーまでジャンプしない症状が発生します。

<ContextualBlock context="docs-growi-org">

該当するリンクは適宜書き換えてください。

::: tip
以前の記法を使って保存されたページの内容は、GROWI 本体をアップグレードしても自動では変更されません。  
マークダウン文書を一括で新しい記法に書き換えるスクリプトを提供していますので、以下のディスカッションを確認してください。  
<https://github.com/weseek/growi/discussions/7180>
:::

</ContextualBlock>


<ContextualBlock context="help-growi-cloud">

::: tip
以前の記法を使って保存されたページの内容は、GROWI をアップグレードしても自動では変更されません。  
ご利用中の GROWI 内に存在する見出しリンクが付与された 「mdcont-」の一括削除を GROWI.cloud サポートにて対応いたします。
ご希望の方はサポートへお問い合わせください。[お問い合わせフォーム](https://growi.cloud/contact)

※ 以下の作業はサポート対応では承っておりません。

- 「mdcont-」の付与
- GROWI 以外の外部ツールに存在する GROWI の見出しリンクに含まれる「mdcont-」の削除対応
:::

</ContextualBlock>

## アップグレード前にチェックすべきこと

<ContextualBlock context="docs-growi-org">

- [x] Node.js v16 以上を利用しているか
- [x] Elasticsearch v7 または v8 を利用しているか
- [x] ソースコードから自身でビルドを行っている場合、新たなビルド手順を確認したか
- [x] `FILE_UPLOAD=local` 設定のシステムで、アップグレード後のファイル移動の手順を確認したか

</ContextualBlock>

- [x] アンカーリンクの仕様変更について
  - [x] ユーザーに周知をしたか
  - [x] 既存のページ内容について、今後の書き換えの戦略は決定したか
