# ページの閲覧/編集権限を設定する

GROWI は、ページごとに閲覧/編集権限を設定できます。新しく作成したページには、自動的に親ページの権限が設定されます。

## 設定方法

1. Edit モードの画面右下の「公開」と表示されたボタンをクリックします。
2. 表示された選択肢の中から、設定したい権限を選びます。
3. 作成/更新ボタンをクリックします。

<img :src="$withBase('/assets/images/ja/authority1.png')" alt="authority1">

## 権限の種類

設定できる権限は、以下の4種類です。

### 1. 公開

- 誰でも閲覧/編集できます。

  ::: tip
  GROWI 全体が `ログインしないと閲覧できない設定` の場合、ログインせずにアクセスした場合は、ログイン画面へリダイレクトされます。ページに `公開` が設定されていたとしても、ログインしていない状態では閲覧できません。
  :::

### 2. リンクを知っている人のみ

- ページの URL を知るユーザーのみが閲覧/編集できます。
- ページツリー、ページリスト、検索結果に表示されません。

  ::: tip
  自分が作成したページのページパスが分からなくなった場合は、ユーザーのホーム画面にある「最近作成したページ」からページを探すことができます。
  :::

  ::: warning
  v5.0 以降、`リンクを知っている人のみ` 設定のページの配下に `公開` や `特定グループのみ` 設定のページが存在した場合、`リンクを知っている人のみ` 設定のページもページツリーやページリストに表示されてしまいます。
  例えば、`リンクを知っている人のみ` 設定の `/Page1` が存在する状態で、`公開` 設定の `/Page1/Page2` を作成すると、ページツリーに `/Page1` と `/Page1/Page2` のどちらも表示されます。
  `リンクを知っている人のみ` を設定する場合は、配下のページ設定に十分お気をつけください。
  :::

### 3. 自分のみ

- 自分のみが閲覧/編集できます。
- ページツリーに表示されません。
- 初期設定では、他のユーザーのページリストと検索結果に表示されます。
  - 設定の変更方法は、 [こちら](/ja/admin-guide/management-cookbook/security.html#ページリストと検索結果に表示するページを制御する)をご参照ください。

### 4. 特定グループのみ

- 設定したグループに属するユーザーのみが閲覧/編集できます。
- ページツリーに表示されません。
- 初期設定では、他のユーザーのページリストと検索結果に表示されます。
  - 設定の変更方法は、[こちら](/ja/admin-guide/management-cookbook/security.html#ページリストと検索結果に表示するページを制御する)をご参照ください。
- グループ管理機能については [こちら](/ja/admin-guide/management-cookbook/group.html)をご参照ください。

## 配下ページに設定できる権限

あるページ `/Page1` の配下ページには、同じ権限か、より強い権限しか設定できません。(v5.0 以降)

以下は、`/Page1` の権限によって、配下ページの `/Page1/child` にどのような権限が設定できるかを示した表です。

| `/Page1` の権限 | `/Page1/child` に設定できる権限 | 可/不可 |
|:--|:------------:|:------------:|
| 公開 | 公開 | :white_check_mark: |
| 公開 | 自分のみ | :white_check_mark: |
| 公開 | 特定グループのみ | :white_check_mark: |
| 公開 | リンクを知っている人のみ | :white_check_mark: |
| リンクを知っている人のみ | 公開 | :white_check_mark: |
| リンクを知っている人のみ | 自分のみ | :white_check_mark: |
| リンクを知っている人のみ | 特定グループのみ | :white_check_mark: |
| リンクを知っている人のみ | リンクを知っている人のみ | :white_check_mark: |
| 自分のみ | 公開 | :x: |
| 自分のみ | 自分のみ | :white_check_mark: |
| 自分のみ | 特定グループのみ | :x: |
| 自分のみ | リンクを知っている人のみ | :white_check_mark: |
| 特定グループのみ | 公開 | :x: |
| 特定グループのみ | 自分のみ | :white_check_mark: |
| 特定グループのみ | 特定グループのみ | (グループの親子関係に依存) |
| 特定グループのみ | リンクを知っている人のみ | :white_check_mark: |

### 「特定グループのみ」を設定したページの場合

`特定グループのみ` を設定した場合、配下ページには同じ権限か、より強い権限(メンバーの範囲が狭いグループ)しか設定できません。

以下は、「社内全体」グループの子グループに「技術部」グループ、更にその子グループに「UI/UXチーム」グループが存在する場合に、配下ページの `/Page1/child` にどのような権限が設定できるかを示した表です。

| `/Page1` の権限 | `/Page1/child` に設定できる権限 | 可/不可 |
|:--|:------------:|:------------:|
| 特定グループのみ(技術部) | 特定グループのみ(技術部) | :white_check_mark: |
| 特定グループのみ(技術部) | 特定グループのみ(社内全体) | :x: |
| 特定グループのみ(技術部) | 特定グループのみ(UI/UXチーム) | :white_check_mark: |

### 「特定グループのみ」を複数グループ設定したページの場合

`特定グループのみ` は複数のグループを設定できます。(v7.0以降)

<img :src="$withBase('/assets/images/ja/authority2.png')" alt="authority2">

ただし、配下ページには同じ権限か、より強い権限(少ない数のグループ)しか設定できません。

以下は、「社内全体」グループの子グループに「技術部」グループ、「営業部」グループ、「人事部」グループが存在する場合に、配下ページの `/Page1/child` にどのような権限が設定できるかを示した表です。

| `/Page1` の権限                  |  `/Page1/child` に設定できる権限 |       可/不可      |  
| :------------------------------- | :------------------------------: | :----------------: |
| 特定グループのみ(技術部、営業部) | 特定グループのみ(技術部、営業部) | :white_check_mark: |  
 | 特定グループのみ(技術部、営業部) |     特定グループのみ(技術部)     | :white_check_mark: |                                 |                                  |                    |  
| 特定グループのみ(技術部)         | 特定グループのみ(技術部、営業部) |         :x:        |  
| 特定グループのみ(技術部、営業部) |     特定グループのみ(人事部)     |         :x:        |  


## 閲覧/編集権限を一括設定する

あるページのすべての配下ページに対して、一括で権限を設定できます。

1. Edit モードで、画面右下に表示される作成/更新ボタンの「▲」をクリックします。
2. 「更新と同時に全ての配下ページのスコープを上書き」をクリックします。

<img :src="$withBase('/assets/images/ja/authority3.png')" alt="authority3">

::: tip
権限設定が必要なページはまとめて整理し、一括で権限設定すると管理が簡単になります。

例:

1. あるグループ名のページを作成する。
2. このグループのみに閲覧/編集権限を付与したいページを、1 で作成したページ配下へ移動する。(ページの移動については [こちら](/ja/guide/features/page_operation.html)をご参照ください。)
3. 1 で作成したページで権限を一括設定する。
:::
